# pystareplotlib

Basic python-based visualization for the [Spatio Temporal Adaptive Resolution Encoding](https://github.com/SpatioTemporal/STARE).

Contact: [Michael Rilee](mike@rilee.net), Rilee Systems Technologies LLC.

# Dependencies

This package depends on several packages that may not be in PyPI.

* STARE
* meshplot

Conda-forge should work for installing these.

# Acknowledgment

2018-2021 STARE development supported by NASA/ACCESS-17.
